Support for "bad" encodings
===========================

.. automodule:: ftfy.bad_codecs

"Sloppy" encodings
------------------
.. automodule:: ftfy.bad_codecs.sloppy

Variants of UTF-8
-----------------
.. automodule:: ftfy.bad_codecs.utf8_variants

